bayespy.inference.vmp.transformations.RotateSwitchingMarkovChain.__init__
=========================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateSwitchingMarkovChain.__init__